==> modal_page-8.x-2.10.tar.gz: modal_page/js/modal-page.js <==
/**
 * @file
 * Default JavaScript file for Modal Page.
 */

(function ($, Drupal, drupalSettings) {
  'use strict';

  Drupal.behaviors.modalPage = {
    attach: function (context, settings) {

      var modalPage = $('#js-modal-page-show-modal', context);

      if (modalPage.length) {

        var modal_id = $('#js-modal-page-show-modal', context).attr('data-modal-id');
        var cookie_please_do_not_show_again = $.cookie(modal_id);

        if (!cookie_please_do_not_show_again) {
          var delay = $('#js-modal-page-show-modal #delay_display', context).val() * 1000;
          setTimeout(function () {
            modalPage.modal();
          }, delay);
        }
      }

      var checkbox_please_do_not_show_again = $('.modal-page-please-do-not-show-again', context);
      var ok_buttom = $('.js-modal-page-ok-buttom', context);

      ok_buttom.on('click', function () {

        if (checkbox_please_do_not_show_again.is(':checked')) {

          var id_modal = checkbox_please_do_not_show_again.val();

          $.cookie(id_modal, 'please_do_not_show_again', {expires: 365 * 20 });

        }
      });

      // Open Modal Page clicking on "open-modal-page" class.
      $('.open-modal-page', context).on('click', function () {
        modalPage.modal();
      });

      // Open Modal Page clicking on user custom class.
      if (typeof settings.modal_page != 'undefined' && settings.modal_page.open_modal_on_element_click) {
        var link_open_modal = $(settings.modal_page.open_modal_on_element_click, context);
        link_open_modal.on('click', function () {
          modalPage.modal();
        });
      }
    }
  };
})(jQuery, Drupal, drupalSettings);

==> modal_page-8.x-2.11.tar.gz: modal_page/js/modal-page.js <==
/**
 * @file
 * Default JavaScript file for Modal Page.
 */

(function ($, Drupal, drupalSettings) {
  'use strict';

  Drupal.behaviors.modalPage = {
    attach: function (context, settings) {

      var modalPage = $('#js-modal-page-show-modal', context);

      if (modalPage.length) {

        var modal_id = $('#js-modal-page-show-modal', context).attr('data-modal-id');
        var cookie_please_do_not_show_again = $.cookie(modal_id);
        var auto_open = true;

        // Check auto-open.
        if (typeof settings.modal_page != 'undefined' && settings.modal_page.auto_open) {
          var auto_open = settings.modal_page.auto_open;
        }
        
        if (auto_open == true && !cookie_please_do_not_show_again) {
          var delay = $('#js-modal-page-show-modal #delay_display', context).val() * 1000;
          setTimeout(function () {
            modalPage.modal();
          }, delay);
        }
      }

      var checkbox_please_do_not_show_again = $('.modal-page-please-do-not-show-again', context);
      var ok_buttom = $('.js-modal-page-ok-buttom', context);

      ok_buttom.on('click', function () {

        if (checkbox_please_do_not_show_again.is(':checked')) {

          var id_modal = checkbox_please_do_not_show_again.val();

          $.cookie(id_modal, 'please_do_not_show_again', {expires: 365 * 20 });

        }
      });

      // Open Modal Page clicking on "open-modal-page" class.
      $('.open-modal-page', context).on('click', function () {
        modalPage.modal();
      });

      // Open Modal Page clicking on user custom class.
      if (typeof settings.modal_page != 'undefined' && settings.modal_page.open_modal_on_element_click) {
        var link_open_modal = $(settings.modal_page.open_modal_on_element_click, context);
        link_open_modal.on('click', function () {
          modalPage.modal();
        });
      }
    }
  };
})(jQuery, Drupal, drupalSettings);
